==> botserver-2.0.118.tgz: package/packages/default.gbui/src/players/GBBulletPlayer.js <==
/*****************************************************************************\
|                                               ( )_  _                       |
|    _ _    _ __   _ _    __    ___ ___     _ _ | ,_)(_)  ___   ___     _     |
|   ( '_`\ ( '__)/'_` ) /'_ `\/' _ ` _ `\ /'_` )| |  | |/',__)/' v `\ /'_`\   |
|   | (_) )| |  ( (_| |( (_) || ( ) ( ) |( (_| || |_ | |\__, \| (˅) |( (_) )  |
|   | ,__/'(_)  `\__,_)`\__  |(_) (_) (_)`\__,_)`\__)(_)(____/(_) (_)`\___/'  |
|   | |                ( )_) |                                                |
|   (_)                 \___/'                                                |
|                                                                             |
| General Bots Copyright (c) Pragmatismo.io. All rights reserved.             |
| Licensed under the AGPL-3.0.                                                |
|                                                                             |
| According to our dual licensing model, this program can be used either      |
| under the terms of the GNU Affero General Public License, version 3,        |
| or under a proprietary license.                                             |
|                                                                             |
| The texts of the GNU Affero General Public License with an additional       |
| permission and of our proprietary license can be found at and               |
| in the LICENSE file you have received along with this program.              |
|                                                                             |
| This program is distributed in the hope that it will be useful,             |
| but WITHOUT ANY WARRANTY; without even the implied warranty of              |
| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the                |
| GNU Affero General Public License for more details.                         |
|                                                                             |
| "General Bots" is a registered trademark of Pragmatismo.io.                 |
| The licensing of the program under the AGPLv3 does not imply a              |
| trademark license. Therefore any rights, title and interest in              |
| our trademarks remain entirely with us.                                     |
|                                                                             |
\*****************************************************************************/

import React, { Component } from "react";


class RenderItem extends Component {
  send(item) {
    setTimeout(()=>{
    window.botConnection
      .postActivity({
        type: "event",
        name: "answerEvent",
        data: item.questionId,
        locale: "en-us",
        textFormat: "plain",
        timestamp: new Date().toISOString(),
        from: window.user
      })
      .subscribe(console.log("success"));
    },400);
  }

  render() {
    return (
      <ul>
        {this.props.list.map((item, i) => (
          <li key={item.questionId}>
            <label className="gb-bullet-player-item" onClick={this.send.bind(this, item)}>{item.content}</label>
          </li>
        ))}
      </ul>
    );
  }
}

class GBBulletPlayer extends Component {
  constructor() {
    super();
    this.state = {
      list: []
    };
  }

  play(data) {
    this.setState({ list: data });
  }

  stop() {
    this.setState({ list: [] });
  }

  render() {
    return (
      <div
        className="gb-bullet-player"
        ref={i => (this.playerText = i)}
      >
        <RenderItem
          app={this.props.app}
          list={this.state.list}
          ref={i => (this.playerList = i)}
        />
      </div>
    );
  }
}

export default GBBulletPlayer;

==> botserver-2.4.41.tgz: package/packages/default.gbui/src/players/GBBulletPlayer.js <==
/*****************************************************************************\
|                                               ( )_  _                       |
|    _ _    _ __   _ _    __    ___ ___     _ _ | ,_)(_)  ___   ___     _     |
|   ( '_`\ ( '__)/'_` ) /'_ `\/' _ ` _ `\ /'_` )| |  | |/',__)/' v `\ /'_`\   |
|   | (_) )| |  ( (_| |( (_) || ( ) ( ) |( (_| || |_ | |\__, \| (˅) |( (_) )  |
|   | ,__/'(_)  `\__,_)`\__  |(_) (_) (_)`\__,_)`\__)(_)(____/(_) (_)`\___/'  |
|   | |                ( )_) |                                                |
|   (_)                 \___/'                                                |
|                                                                             |
| General Bots Copyright (c) Pragmatismo.io. All rights reserved.             |
| Licensed under the AGPL-3.0.                                                |
|                                                                             |
| According to our dual licensing model, this program can be used either      |
| under the terms of the GNU Affero General Public License, version 3,        |
| or under a proprietary license.                                             |
|                                                                             |
| The texts of the GNU Affero General Public License with an additional       |
| permission and of our proprietary license can be found at and               |
| in the LICENSE file you have received along with this program.              |
|                                                                             |
| This program is distributed in the hope that it will be useful,             |
| but WITHOUT ANY WARRANTY; without even the implied warranty of              |
| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the                |
| GNU Affero General Public License for more details.                         |
|                                                                             |
| "General Bots" is a registered trademark of Pragmatismo.io.                 |
| The licensing of the program under the AGPLv3 does not imply a              |
| trademark license. Therefore any rights, title and interest in              |
| our trademarks remain entirely with us.                                     |
|                                                                             |
\*****************************************************************************/

import React, { Component } from "react";


class RenderItem extends Component {
  send(item) {
    setTimeout(()=>{
    window.botConnection
      .postActivity({
        type: "event",
        name: "answerEvent",
        data: item.questionId,
        locale: "en-us",
        textFormat: "plain",
        timestamp: new Date().toISOString(),
        from: window.user
      })
    },400);
  }

  render() {
    return (
      <ul>
        {this.props.list.map((item) => (
          <li key={item.questionId}>
            <label className="gb-bullet-player-item" onClick={this.send.bind(this, item)}>{item.content}</label>
          </li>
        ))}
      </ul>
    );
  }
}

class GBBulletPlayer extends Component {
  constructor() {
    super();
    this.state = {
      list: []
    };
  }

  play(data) {
    this.setState({ list: data });
  }

  stop() {
    this.setState({ list: [] });
  }

  render() {
    return (
      <div
        className="gb-bullet-player"
        ref={i => (this.playerText = i)}
      >
        <RenderItem
          app={this.props.app}
          list={this.state.list}
          ref={i => (this.playerList = i)}
        />
      </div>
    );
  }
}

export default GBBulletPlayer;
